import {
  select,
  forceSimulation,
  forceManyBody,
  forceLink,
  forceCenter,
  drag,
} from 'd3';

import { nodes, links } from './data';
// Accessing the svg attributes 
const svg = select('#container');
const width = +svg.attr('width');
const height = +svg.attr('height');
const centerX = width/2 ;
const centerY = height/4;

// Adding force to the simulation
const simulation = forceSimulation(nodes)
  .force('charge', forceManyBody().strength(-1000))  // Strength is used to repel or attract nodes
  .force(
    'link',
    forceLink(links))
  .force('center', forceCenter(centerX, centerY));

// To create liness
const lines = svg
  .selectAll('line')
  .data(links)
  .enter()
  .append('line')
  .attr('stroke','black');

// Append circle for each node
const circles = svg
  .selectAll('circle')  
  .data(nodes)
  .enter()
  .append('circle')
  .attr('fill',(node) => node.color ||'gray')  //If node.color is undefined , grey is the default
  .attr('r', (node) => node.size);

// Adding text to the nodes
const text = svg
  .selectAll('text')
  .data(nodes)
  .enter()
  .append('text')
  .attr('text-anchor', 'middle')
  .attr('alignment-baseline', 'middle')  // To align the text in the middle
  .text((node) => node.id);

// Starts automatically and use simulation on for tick events
simulation.on('tick', () => {
  circles.attr('cx', (node) => node.x).attr('cy', (node) => node.y);
  text.attr('x', (node) => node.x).attr('y', (node) => node.y);

  // X and Y coordinates to position
  lines
    .attr('x1', (link) => link.source.x)
    .attr('y1', (link) => link.source.y)
    .attr('x2', (link) => link.target.x)
    .attr('y2', (link) => link.target.y);
});
